@@ -262,7 +262,8 @@ parse_hydro_response <- function(res, raw = FALSE){
     base_skip <- 1
     raw       <- suppressMessages(read.csv(text = res, skip = base_skip,
                                            stringsAsFactors = FALSE, row.names = NULL))
-    i         <- 1 + min(which(apply(raw[,10:16], 1, function(x) all(is.na(x)))))
+    i         <- 1 + min(which(apply(raw[,10:16], 1, function(x) all(is.na(x) |
+                                                                       nchar(x) == 0))))
 
     # metadata should have type and units columns
     metadata  <- suppressMessages(read.csv(text = res, skip = base_skip,
